# [2.4.4](https://github.com/seriaati/enka-py/compare/v2.4.3..v2.4.4) - 2025-01-15

## Bug Fixes

- Temp fix for fight prop type 77 - ([20a297e](https://github.com/seriaati/enka-py/commit/20a297e60375d9441a8caf5a3bfbdc1877d0d877))
-  [**breaking**]Prevent error due to unrecognized enum value - ([f03f242](https://github.com/seriaati/enka-py/commit/f03f242bbfbc1ab7a4efac853206b1f0eb8f4ec0))

## Documentation

- Update package renaming notice - ([e6bdae9](https://github.com/seriaati/enka-py/commit/e6bdae9694fb3b427ccc8c0abd9eba64d568d428))

## Features

- Add new enums for 3.0 - ([172e740](https://github.com/seriaati/enka-py/commit/172e7406f052a724bb4e8485443ca1e96cb98777))

## Miscellaneous Chores

- **(deps)** update astral-sh/ruff-action action to v3 ([#82](https://github.com/seriaati/enka-py/issues/82)) - ([deb461d](https://github.com/seriaati/enka-py/commit/deb461d41f841d4d06fb2cb8613909e7ea5aa3a4))
- **(deps)** lock file maintenance ([#84](https://github.com/seriaati/enka-py/issues/84)) - ([b540f6e](https://github.com/seriaati/enka-py/commit/b540f6ec1328a4c5106916881b122cce597445d6))
- **(deps)** lock file maintenance ([#85](https://github.com/seriaati/enka-py/issues/85)) - ([b926866](https://github.com/seriaati/enka-py/commit/b926866e391f60a8ca64b1fb80aa2b920ff4719c))
- Rename project to enka - ([b6db026](https://github.com/seriaati/enka-py/commit/b6db026e8f3de6000967eb924250cc2145786b74))

